'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.iconLink = iconLink;
exports.appleIconLink = appleIconLink;
exports.msSquare = msSquare;
exports.default = addFavicon;
var appleIconRel = 'apple-touch-icon-precomposed';
var pngType = 'image/png';

function iconLink(href, size) {
  var type = arguments.length <= 2 || arguments[2] === undefined ? pngType : arguments[2];

  return { rel: 'icon', type: type, href: href, sizes: size + 'x' + size };
}

function appleIconLink(href, size) {
  return { rel: appleIconRel, href: href, sizes: size + 'x' + size };
}

function msSquare(content, size) {
  return { name: 'msapplication-square' + size + 'x' + size + 'logo', content: content };
}

function addFavicon(_ref, meta, link) {
  var ico = _ref.ico;
  var s16 = _ref.s16;
  var s32 = _ref.s32;
  var s57 = _ref.s57;
  var s60 = _ref.s60;
  var s70 = _ref.s70;
  var s72 = _ref.s72;
  var s76 = _ref.s76;
  var s96 = _ref.s96;
  var s114 = _ref.s114;
  var s120 = _ref.s120;
  var s128 = _ref.s128;
  var s144 = _ref.s144;
  var s150 = _ref.s150;
  var s152 = _ref.s152;
  var s196 = _ref.s196;
  var s310 = _ref.s310;
  var s310x150 = _ref.s310x150;

  if (ico) link.push({ rel: 'shortcut icon', href: ico });
  // <link rel="icon" sizes="16x16 32x32" href="/favicon.ico?v=2">

  if (s16) link.push(iconLink(s16, 16));
  if (s32) link.push(iconLink(s32, 32));
  if (s96) link.push(iconLink(s96, 96));
  if (s128) link.push(iconLink(s128, 128));
  if (s196) link.push(iconLink(s196, 196));

  if (s57) link.push(appleIconLink(s57, 57));
  if (s60) link.push(appleIconLink(s60, 60));
  if (s72) link.push(appleIconLink(s72, 72));
  if (s76) link.push(appleIconLink(s76, 76));
  if (s114) link.push(appleIconLink(s114, 114));
  if (s120) link.push(appleIconLink(s120, 120));
  if (s144) link.push(appleIconLink(s144, 144));
  if (s152) link.push(appleIconLink(s152, 152));

  // TODO <meta name="msapplication-TileColor" content="#FFFFFF" />
  if (s144) meta.push({ name: 'msapplication-TileImage', content: s144 });

  if (s70) meta.push(msSquare(s70, 70));
  if (s150) meta.push(msSquare(s150, 150));
  if (s310) meta.push(msSquare(s310, 310));

  if (s310x150) meta.push({ name: 'msapplication-wide310x150logo', content: s310x150 });
}