'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Hat = exports.toHelmetProps = undefined;

var _templateObject = _taggedTemplateLiteral(['{\n  base: String | {\n    target: String\n    href: String\n  }\n  defaultTitle: String\n  description: String\n  favicon: Object\n  image: String\n  link: [{\n    rel: String\n    href: String\n  }!]\n  meta: [{\n    name: String\n    content: String\n  }!]\n  og: Object\n  property: Object\n  siteName: String\n  title: String\n  titleTemplate: String\n  twitter: Object\n  url: String\n}'], ['{\n  base: String | {\n    target: String\n    href: String\n  }\n  defaultTitle: String\n  description: String\n  favicon: Object\n  image: String\n  link: [{\n    rel: String\n    href: String\n  }!]\n  meta: [{\n    name: String\n    content: String\n  }!]\n  og: Object\n  property: Object\n  siteName: String\n  title: String\n  titleTemplate: String\n  twitter: Object\n  url: String\n}']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactHelmet = require('react-helmet');

var _reactHelmet2 = _interopRequireDefault(_reactHelmet);

var _proptypesParser = require('proptypes-parser');

var _util = require('./util');

var _favicon = require('./favicon');

var _favicon2 = _interopRequireDefault(_favicon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var twitterTitleMaxLen = 70;
var twitterDescMaxLen = 200;

var hasObjectItem = function hasObjectItem(arr, name, value) {
  return (0, _util.findIndex)(arr, function (_ref) {
    var val = _ref[name];
    return val === value;
  }) >= 0;
};

var toHelmetProps = function toHelmetProps(_ref2) {
  var base = _ref2.base;
  var defaultTitle = _ref2.defaultTitle;
  var description = _ref2.description;
  var favicon = _ref2.favicon;
  var image = _ref2.image;
  var link = _ref2.link;
  var meta = _ref2.meta;
  var og = _ref2.og;
  var property = _ref2.property;
  var siteName = _ref2.siteName;
  var title = _ref2.title;
  var titleTemplate = _ref2.titleTemplate;
  var twitter = _ref2.twitter;
  var url = _ref2.url;

  var rest = _objectWithoutProperties(_ref2, ['base', 'defaultTitle', 'description', 'favicon', 'image', 'link', 'meta', 'og', 'property', 'siteName', 'title', 'titleTemplate', 'twitter', 'url']);

  link = link || [];
  meta = meta || [];
  og = og || {};
  twitter = twitter || {};

  // TODO: itemProp

  // siteName
  if (siteName != null) {
    if (defaultTitle == null) defaultTitle = siteName;
    if (titleTemplate === true) titleTemplate = '%s | ' + siteName;
    if (og.site_name == null) og.site_name = siteName;
    if (!hasObjectItem(meta, 'name', 'application-name')) {
      meta.push({ name: 'application-name', content: siteName });
    }
  }

  // favicon
  if (favicon) {
    (0, _favicon2.default)(favicon, meta, link);
  }

  // title
  if (title != null) {
    if (og.title == null) og.title = title;
    if (twitter.title == null) twitter.title = title;
  }
  if (twitter.title) {
    twitter.title = (0, _util.truncate)(twitter.title, twitterTitleMaxLen, '...');
  }

  // description
  if (description != null) {
    if (og.description == null) og.description = description;
    if (twitter.description == null) twitter.description = description;
    if (!hasObjectItem(meta, 'name', 'description')) {
      meta.push({ name: 'description', content: description });
    }
  }
  if (twitter.description) {
    twitter.description = (0, _util.truncate)(twitter.description, twitterDescMaxLen, '...');
  }

  // image
  if (image != null) {
    if (og.image == null) og.image = image;
    if (twitter.image == null) twitter.image = image;
    if (!hasObjectItem(link, 'rel', 'apple-touch-startup-image')) {
      link.push({ rel: 'apple-touch-startup-image', href: image });
    }
  }

  // url
  if (url != null) {
    if (og.url == null) og.url = url;
    if (twitter.url == null) twitter.url = url;
    if (!hasObjectItem(link, 'rel', 'canonical')) {
      link.push({ rel: 'canonical', href: url });
    }
  }

  // og
  (0, _util.forEach)(og, function (content, prop) {
    return content != null && meta.push({ property: 'og:' + prop, content: content });
  });

  // twitter
  (0, _util.forEach)(twitter, function (content, prop) {
    return content != null && meta.push({ property: 'twitter:' + prop, content: content });
  });

  // property
  if (property) {
    (0, _util.forEach)(property, function (props, namespace) {
      return (0, _util.forEach)(props, function (content, prop) {
        return content != null && meta.push({ property: namespace + ':' + prop, content: content });
      });
    });
  }

  // rest
  if (base != null) rest.base = typeof base === 'string' ? { href: base } : base;
  if (defaultTitle != null) rest.defaultTitle = defaultTitle;
  if (link.length) rest.link = link;
  if (meta.length) rest.meta = meta;
  if (title != null) rest.title = title;
  if (titleTemplate != null) rest.titleTemplate = titleTemplate;

  /**
   * @param {Object} htmlAttributes: {"lang": "en", "amp": undefined}
   * @param {String} title: "Title"
   * @param {String} defaultTitle: "Default Title"
   * @param {String} titleTemplate: "MySite.com - %s"
   * @param {Object} base: {"target": "_blank", "href": "http://mysite.com/"}
   * @param {Array} meta: [{"name": "description", "content": "Test description"}]
   * @param {Array} link: [{"rel": "canonical", "href": "http://mysite.com/example"}]
   * @param {Array} script: [{"type": "text/javascript", "src": "http://mysite.com/js/test.js"}]
   * @param {Array} style: [{"type": "text/css", "cssText": "div{ display: block; color: blue; }"}]
   * @param {Function} onChangeClientState: "(newState) => console.log(newState)"
   */
  return rest;
};

var Hat = function Hat(props) {
  return _react2.default.createElement(_reactHelmet2.default, toHelmetProps(props));
};

Hat.propTypes = (0, _proptypesParser.PT)(_templateObject);

exports.toHelmetProps = toHelmetProps;
exports.Hat = Hat;
exports.default = Hat;